## 0.0.44

This new version includes a variety of enhancements and new features, including the addition of new notebooks, improvements to the Zotero and QueryBot functionalities, and the integration of Google Calendar API.

### New Features

- Added blogging assistant and gcal notebooks for blog tagger, summarizer, and Google Calendar related tasks. Also, updated existing notebooks for cache and Zotero with new features and improvements (2378760) (Eric Ma)
- Implemented updates to all attendees on event creation and update in Google Calendar (57f80de) (Eric Ma)
- Refactored Zotero library handling and improved chat_paper functionality (b160982) (Eric Ma)
- Improved index handling and document processing in QueryBot (ea47ec9) (Eric Ma)
- Refactored sync function in Zotero and added chat_paper command (237631e) (Eric Ma)
- Added sync command to sync Zotero items to local JSON file (b1ccf350) (Eric Ma)
- Created .llamabot directory and updated config path (6e1b457) (Eric Ma)
- Added zotero integration and refactored configure function in CLI (0add77a) (Eric Ma)
- Added rich library to dependencies for better terminal output and formatting (d4c21d1) (Eric Ma)
- Added environment variable configuration in cli/utils (3ba93ef) (Eric Ma)
- Added initial CLI configuration for Zotero integration (8a3deb2) (Eric Ma)
- Added progress display for commit and push operations (9d9c86e) (Eric Ma)
- Added capture_errors decorator in google/utility_functions (12a7a3c) (Eric Ma)
- Added Google Calendar API integration (5c6ba9f) (Eric Ma)
- Added hashing for scopes and credentials in token file name in Google API (24d774b) (Eric Ma)
- Added llamabot_config_dir variable in config (2622ef3) (Eric Ma)
- Added convenience wrappers for Google API (0ea502d) (Eric Ma)
- Added tutorial bot and prompts in prompt_library (fe0d717) (Eric Ma)
- Added tutorial module to CLI (436374b) (Eric Ma)
- Added file_finder module documentation (dff0c71) (Eric Ma)

### Refactor

- Simplified chat_paper function and improved document loading in Zotero (7f3e2d0) (Eric Ma)
- Updated index with a new document and set default values for chunk_size and chunk_overlap in QueryBot (02e21f8) (Eric Ma)
- Restructured Google API wrapper (88464cc) (Eric Ma)
- Separated credential loading from calendar service creation in Google API (39c038d) (Eric Ma)
- Moved code block in tests function in prompt_library (a2e5453) (Eric Ma)
- Improved commit message handling and progress display in cli/git (55e6aa8) (Eric Ma)
- Renamed test_coding.py to test_coding_prompt_library.py in tests (260c989) (Eric Ma)
- Centralized llamabotrc_paths and updated imports in config (f3af30d) (Eric Ma)
- Removed unused tutorial_writer function in cli (407f687) (Eric Ma)
- Updated commit message guidelines in prompt_library/git (185649c) (Eric Ma)

### Docs

- Updated pip install command in python.md (84b079a) (Eric Ma)
- Added Llamabot Python CLI tutorial (d85d039) (Eric Ma)
